@@ -1,6 +1,6 @@
 package Mail::BIMI::Role::HasHTTPClient;
 # ABSTRACT: Class to model a HTTP client
-our $VERSION = '3.20210301'; # VERSION
+our $VERSION = '3.20210512'; # VERSION
 use 5.20.0;
 use Moose::Role;
 use Mail::BIMI::Prelude;
@@ -15,13 +15,16 @@ requires 'http_client_max_fetch_size';
   my $http_client;
   sub _build_http_client($self) {
     return $http_client if $http_client;
-    my $agent = 'Mail::BIMI ' . ( $Mail::BIMI::Version // 'dev' );
+    my $agent = 'Mail::BIMI ' . ( $Mail::BIMI::Version // 'dev' ) . '/1.0';
     $http_client = HTTP::Tiny::Paranoid->new(
       agent => $agent,
       max_size => $self->http_client_max_fetch_size,
       max_redirect => $self->bimi_object->options->http_client_max_redirect,
       timeout => $self->bimi_object->options->http_client_timeout,
       verify_SSL => 1,     # Certificates MUST verify
+      default_headers => {
+        'accept-encoding' => 'identity',
+      },
     );
     return $http_client;
   }
@@ -41,7 +44,7 @@ Mail::BIMI::Role::HasHTTPClient - Class to model a HTTP client
 
 =head1 VERSION
 
-version 3.20210301
+version 3.20210512
 
 =head1 DESCRIPTION
 
